@@ -4,6 +4,7 @@
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2002 Red Hat, Inc.
  * Copyright (C) 2003 Rob Adams
+ * Copyright (C) 2004, 2005 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +33,7 @@
 #include <X11/Xlib.h>
 #include "eventqueue.h"
 #include "common.h"
+#include "boxes.h"
 
 #ifdef HAVE_STARTUP_NOTIFICATION
 #include <libsn/sn.h>
@@ -43,17 +45,6 @@
 
 #define meta_XFree(p) do { if ((p)) XFree ((p)); } while (0)
 
-/* this doesn't really belong here, oh well. */
-typedef struct _MetaRectangle MetaRectangle;
-
-struct _MetaRectangle
-{
-  int x;
-  int y;
-  int width;
-  int height;
-};
-
 typedef struct MetaCompositor  MetaCompositor;
 typedef struct _MetaDisplay    MetaDisplay;
 typedef struct _MetaFrame      MetaFrame;
@@ -67,6 +58,8 @@ typedef struct _MetaWorkspace  MetaWorkspace;
 typedef struct _MetaWindowPropHooks MetaWindowPropHooks;
 typedef struct _MetaGroupPropHooks  MetaGroupPropHooks;
 
+typedef struct MetaEdgeResistanceData MetaEdgeResistanceData;
+
 typedef void (* MetaWindowPingFunc) (MetaDisplay *display,
 				     Window       xwindow,
 				     Time         timestamp,
@@ -183,6 +176,8 @@ struct _MetaDisplay
   Atom atom_net_desktop_geometry;
   Atom atom_net_desktop_viewport;
   Atom atom_metacity_version;
+  Atom atom_net_wm_visible_name;
+  Atom atom_net_wm_visible_icon_name;
 
   /* This is the actual window from focus events,
    * not the one we last set
@@ -277,6 +272,7 @@ struct _MetaDisplay
   int         grab_wireframe_last_display_width;
   int         grab_wireframe_last_display_height;
   GList*      grab_old_window_stacking;
+  MetaEdgeResistanceData *grab_edge_resistance_data;
   
   /* we use property updates as sentinels for certain window focus events
    * to avoid some race conditions on EnterNotify events
@@ -347,6 +343,7 @@ struct _MetaDisplay
   int render_error_base;
 #endif
 #ifdef HAVE_XSYNC
+  unsigned int grab_last_user_action_was_snap;
   unsigned int have_xsync : 1;
 #define META_DISPLAY_HAS_XSYNC(display) ((display)->have_xsync)
 #else
@@ -456,6 +453,10 @@ void meta_display_grab_focus_window_button   (MetaDisplay *display,
 void meta_display_ungrab_focus_window_button (MetaDisplay *display,
                                               MetaWindow  *window);
 
+/* Next two functions are defined in edge-resistance.c */
+void meta_display_compute_resistance_and_snapping_edges (MetaDisplay *display);
+void meta_display_cleanup_edges                         (MetaDisplay *display);
+
 /* make a request to ensure the event serial has changed */
 void     meta_display_increment_event_serial (MetaDisplay *display);
 
@@ -487,8 +488,6 @@ typedef enum
 {
   META_TAB_LIST_NORMAL,
   META_TAB_LIST_DOCKS
-  
-
 } MetaTabList;
 
 GList* meta_display_get_tab_list (MetaDisplay   *display,
@@ -513,12 +512,6 @@ int meta_resize_gravity_from_grab_op (MetaGrabOp op);
 gboolean meta_grab_op_is_moving   (MetaGrabOp op);
 gboolean meta_grab_op_is_resizing (MetaGrabOp op);
 
-gboolean meta_rectangle_intersect (MetaRectangle *src1,
-                                   MetaRectangle *src2,
-                                   MetaRectangle *dest);
-gboolean meta_rectangle_equal (const MetaRectangle *src1,
-                               const MetaRectangle *src2);
-
 void meta_display_devirtualize_modifiers (MetaDisplay        *display,
                                           MetaVirtualModifier modifiers,
                                           unsigned int       *mask);
